Coverage for markupmirror.urls: 100%

# Coverage for markupmirror.urls : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | from django.conf.urls import patterns from django.conf.urls import url from django.views.generic.base import TemplateView from markupmirror.views import MarkupPreview urlpatterns = patterns('', url(r'^preview/$', MarkupPreview.as_view(), name='preview'), url(r'^base/$', TemplateView.as_view( template_name='markupmirror/preview.html'), name='base'), ) # Default namespace registration for include('markupmirror.urls.preview') # (urlpatterns, app_name, namespace) preview = (urlpatterns, 'markupmirror', 'markupmirror') __all__ = ('preview',)